# MirrorballPackage

The package is built to combine two images eg. scenary, paintings etc and superimpose the styles and content of the images to create a new image. This can be a useful inspiration
to the new painters and other content creators.
This can also be used to check the authenticity of an image by comparing the given two images and checking the total loss.
There are two important functions which a user can access which are:

**1)run_style_transfer:**
                       
                       Input : Content image path , Style image path , number of iterations , weight of content image , weight of style image
                       Output : Returns the superimposed image and the total loss
                       

**2)show_results:**
                       
                       Input : Best image , Content image path , Style image path ,  show_final_large 
                       Output : Returns the original and final images 
                                                     
